@@ -8,15 +8,14 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_autoscaling._jsii
-import aws_cdk.aws_ec2._jsii
-import aws_cdk.aws_iam._jsii
-import aws_cdk.core._jsii
+from typeguard import check_type
+
+import aws_cdk._jsii
 import cdk_spot_one._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-ec2spot", "0.1.37", __name__[0:-6], "cdk-ec2spot@0.1.37.jsii.tgz"
+    "cdk-ec2spot", "2.0.133", __name__[0:-6], "cdk-ec2spot@2.0.133.jsii.tgz"
 )
 
 __all__ = [
